@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -58,7 +58,7 @@ from .type_defs import (
     UpdateResourceSetResponseTypeDef,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -70,7 +70,7 @@ __all__ = ("Route53RecoveryReadinessClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -87,7 +87,7 @@ class Exceptions:
 
 class Route53RecoveryReadinessClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html)
     """
 
@@ -103,17 +103,17 @@ class Route53RecoveryReadinessClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#can_paginate)
         """
 
     def create_cell(
-        self, *, CellName: str, Cells: List[str] = None, Tags: Dict[str, str] = None
+        self, *, CellName: str, Cells: Sequence[str] = ..., Tags: Mapping[str, str] = ...
     ) -> CreateCellResponseTypeDef:
         """
         Creates a new Cell.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.create_cell)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.create_cell)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#create_cell)
         """
 
@@ -123,27 +123,27 @@ class Route53RecoveryReadinessClient(BaseClient):
         """
         Create a new cross account readiness authorization.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.create_cross_account_authorization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.create_cross_account_authorization)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#create_cross_account_authorization)
         """
 
     def create_readiness_check(
-        self, *, ReadinessCheckName: str, ResourceSetName: str, Tags: Dict[str, str] = None
+        self, *, ReadinessCheckName: str, ResourceSetName: str, Tags: Mapping[str, str] = ...
     ) -> CreateReadinessCheckResponseTypeDef:
         """
         Creates a new Readiness Check.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.create_readiness_check)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.create_readiness_check)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#create_readiness_check)
         """
 
     def create_recovery_group(
-        self, *, RecoveryGroupName: str, Cells: List[str] = None, Tags: Dict[str, str] = None
+        self, *, RecoveryGroupName: str, Cells: Sequence[str] = ..., Tags: Mapping[str, str] = ...
     ) -> CreateRecoveryGroupResponseTypeDef:
         """
         Creates a new Recovery Group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.create_recovery_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.create_recovery_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#create_recovery_group)
         """
 
@@ -152,13 +152,13 @@ class Route53RecoveryReadinessClient(BaseClient):
         *,
         ResourceSetName: str,
         ResourceSetType: str,
-        Resources: List["ResourceTypeDef"],
-        Tags: Dict[str, str] = None
+        Resources: Sequence["ResourceTypeDef"],
+        Tags: Mapping[str, str] = ...
     ) -> CreateResourceSetResponseTypeDef:
         """
         Creates a new Resource Set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.create_resource_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.create_resource_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#create_resource_set)
         """
 
@@ -166,7 +166,7 @@ class Route53RecoveryReadinessClient(BaseClient):
         """
         Deletes an existing Cell.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.delete_cell)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.delete_cell)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#delete_cell)
         """
 
@@ -179,7 +179,7 @@ class Route53RecoveryReadinessClient(BaseClient):
         readiness-2019-12-02/DeleteCrossAccountAuthorization>`_ **Request Syntax**
         response = client.delete_cross_account_authorization( CrossAccountAuth...
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.delete_cross_account_authorization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.delete_cross_account_authorization)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#delete_cross_account_authorization)
         """
 
@@ -187,7 +187,7 @@ class Route53RecoveryReadinessClient(BaseClient):
         """
         Deletes an existing Readiness Check.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.delete_readiness_check)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.delete_readiness_check)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#delete_readiness_check)
         """
 
@@ -195,7 +195,7 @@ class Route53RecoveryReadinessClient(BaseClient):
         """
         Deletes an existing Recovery Group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.delete_recovery_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.delete_recovery_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#delete_recovery_group)
         """
 
@@ -203,32 +203,32 @@ class Route53RecoveryReadinessClient(BaseClient):
         """
         Deletes an existing Resource Set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.delete_resource_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.delete_resource_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#delete_resource_set)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#generate_presigned_url)
         """
 
     def get_architecture_recommendations(
-        self, *, RecoveryGroupName: str, MaxResults: int = None, NextToken: str = None
+        self, *, RecoveryGroupName: str, MaxResults: int = ..., NextToken: str = ...
     ) -> GetArchitectureRecommendationsResponseTypeDef:
         """
         Returns a collection of recommendations to improve resilliance and readiness
         check quality for a Recovery Group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.get_architecture_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.get_architecture_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#get_architecture_recommendations)
         """
 
@@ -236,17 +236,17 @@ class Route53RecoveryReadinessClient(BaseClient):
         """
         Returns information about a Cell.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.get_cell)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.get_cell)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#get_cell)
         """
 
     def get_cell_readiness_summary(
-        self, *, CellName: str, MaxResults: int = None, NextToken: str = None
+        self, *, CellName: str, MaxResults: int = ..., NextToken: str = ...
     ) -> GetCellReadinessSummaryResponseTypeDef:
         """
         Returns information about readiness of a Cell.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.get_cell_readiness_summary)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.get_cell_readiness_summary)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#get_cell_readiness_summary)
         """
 
@@ -254,7 +254,7 @@ class Route53RecoveryReadinessClient(BaseClient):
         """
         Returns information about a ReadinessCheck.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.get_readiness_check)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.get_readiness_check)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#get_readiness_check)
         """
 
@@ -263,24 +263,24 @@ class Route53RecoveryReadinessClient(BaseClient):
         *,
         ReadinessCheckName: str,
         ResourceIdentifier: str,
-        MaxResults: int = None,
-        NextToken: str = None
+        MaxResults: int = ...,
+        NextToken: str = ...
     ) -> GetReadinessCheckResourceStatusResponseTypeDef:
         """
         Returns detailed information about the status of an individual resource within a
         Readiness Check's Resource Set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.get_readiness_check_resource_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.get_readiness_check_resource_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#get_readiness_check_resource_status)
         """
 
     def get_readiness_check_status(
-        self, *, ReadinessCheckName: str, MaxResults: int = None, NextToken: str = None
+        self, *, ReadinessCheckName: str, MaxResults: int = ..., NextToken: str = ...
     ) -> GetReadinessCheckStatusResponseTypeDef:
         """
         Returns information about the status of a Readiness Check.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.get_readiness_check_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.get_readiness_check_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#get_readiness_check_status)
         """
 
@@ -288,17 +288,17 @@ class Route53RecoveryReadinessClient(BaseClient):
         """
         Returns information about a Recovery Group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.get_recovery_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.get_recovery_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#get_recovery_group)
         """
 
     def get_recovery_group_readiness_summary(
-        self, *, RecoveryGroupName: str, MaxResults: int = None, NextToken: str = None
+        self, *, RecoveryGroupName: str, MaxResults: int = ..., NextToken: str = ...
     ) -> GetRecoveryGroupReadinessSummaryResponseTypeDef:
         """
         Returns information about a Recovery Group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.get_recovery_group_readiness_summary)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.get_recovery_group_readiness_summary)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#get_recovery_group_readiness_summary)
         """
 
@@ -306,67 +306,67 @@ class Route53RecoveryReadinessClient(BaseClient):
         """
         Returns information about a Resource Set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.get_resource_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.get_resource_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#get_resource_set)
         """
 
     def list_cells(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListCellsResponseTypeDef:
         """
         Returns a collection of Cells.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.list_cells)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.list_cells)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#list_cells)
         """
 
     def list_cross_account_authorizations(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListCrossAccountAuthorizationsResponseTypeDef:
         """
         Returns a collection of cross account readiness authorizations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.list_cross_account_authorizations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.list_cross_account_authorizations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#list_cross_account_authorizations)
         """
 
     def list_readiness_checks(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListReadinessChecksResponseTypeDef:
         """
         Returns a collection of Readiness Checks.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.list_readiness_checks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.list_readiness_checks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#list_readiness_checks)
         """
 
     def list_recovery_groups(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListRecoveryGroupsResponseTypeDef:
         """
         Returns a collection of Recovery Groups.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.list_recovery_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.list_recovery_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#list_recovery_groups)
         """
 
     def list_resource_sets(
-        self, *, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListResourceSetsResponseTypeDef:
         """
         Returns a collection of Resource Sets.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.list_resource_sets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.list_resource_sets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#list_resource_sets)
         """
 
     def list_rules(
-        self, *, MaxResults: int = None, NextToken: str = None, ResourceType: str = None
+        self, *, MaxResults: int = ..., NextToken: str = ..., ResourceType: str = ...
     ) -> ListRulesResponseTypeDef:
         """
         Returns a collection of rules that are applied as part of Readiness Checks.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.list_rules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.list_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#list_rules)
         """
 
@@ -374,31 +374,31 @@ class Route53RecoveryReadinessClient(BaseClient):
         """
         Returns a list of the tags assigned to the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.list_tags_for_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.list_tags_for_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#list_tags_for_resources)
         """
 
-    def tag_resource(self, *, ResourceArn: str, Tags: Dict[str, str]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceArn: str, Tags: Mapping[str, str]) -> Dict[str, Any]:
         """
         Adds tags to the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, ResourceArn: str, TagKeys: List[str]) -> None:
+    def untag_resource(self, *, ResourceArn: str, TagKeys: Sequence[str]) -> None:
         """
         Removes tags from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#untag_resource)
         """
 
-    def update_cell(self, *, CellName: str, Cells: List[str]) -> UpdateCellResponseTypeDef:
+    def update_cell(self, *, CellName: str, Cells: Sequence[str]) -> UpdateCellResponseTypeDef:
         """
         Updates an existing Cell.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.update_cell)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.update_cell)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#update_cell)
         """
 
@@ -408,27 +408,27 @@ class Route53RecoveryReadinessClient(BaseClient):
         """
         Updates an exisiting Readiness Check.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.update_readiness_check)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.update_readiness_check)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#update_readiness_check)
         """
 
     def update_recovery_group(
-        self, *, Cells: List[str], RecoveryGroupName: str
+        self, *, Cells: Sequence[str], RecoveryGroupName: str
     ) -> UpdateRecoveryGroupResponseTypeDef:
         """
         Updates an existing Recovery Group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.update_recovery_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.update_recovery_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#update_recovery_group)
         """
 
     def update_resource_set(
-        self, *, ResourceSetName: str, ResourceSetType: str, Resources: List["ResourceTypeDef"]
+        self, *, ResourceSetName: str, ResourceSetType: str, Resources: Sequence["ResourceTypeDef"]
     ) -> UpdateResourceSetResponseTypeDef:
         """
         Updates an existing Resource Set.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.update_resource_set)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Client.update_resource_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/client.html#update_resource_set)
         """
 
@@ -437,7 +437,7 @@ class Route53RecoveryReadinessClient(BaseClient):
         self, operation_name: Literal["get_cell_readiness_summary"]
     ) -> GetCellReadinessSummaryPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.GetCellReadinessSummary)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.GetCellReadinessSummary)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/paginators.html#getcellreadinesssummarypaginator)
         """
 
@@ -446,7 +446,7 @@ class Route53RecoveryReadinessClient(BaseClient):
         self, operation_name: Literal["get_readiness_check_resource_status"]
     ) -> GetReadinessCheckResourceStatusPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.GetReadinessCheckResourceStatus)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.GetReadinessCheckResourceStatus)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/paginators.html#getreadinesscheckresourcestatuspaginator)
         """
 
@@ -455,7 +455,7 @@ class Route53RecoveryReadinessClient(BaseClient):
         self, operation_name: Literal["get_readiness_check_status"]
     ) -> GetReadinessCheckStatusPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.GetReadinessCheckStatus)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.GetReadinessCheckStatus)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/paginators.html#getreadinesscheckstatuspaginator)
         """
 
@@ -464,14 +464,14 @@ class Route53RecoveryReadinessClient(BaseClient):
         self, operation_name: Literal["get_recovery_group_readiness_summary"]
     ) -> GetRecoveryGroupReadinessSummaryPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.GetRecoveryGroupReadinessSummary)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.GetRecoveryGroupReadinessSummary)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/paginators.html#getrecoverygroupreadinesssummarypaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_cells"]) -> ListCellsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListCells)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListCells)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/paginators.html#listcellspaginator)
         """
 
@@ -480,7 +480,7 @@ class Route53RecoveryReadinessClient(BaseClient):
         self, operation_name: Literal["list_cross_account_authorizations"]
     ) -> ListCrossAccountAuthorizationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListCrossAccountAuthorizations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListCrossAccountAuthorizations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/paginators.html#listcrossaccountauthorizationspaginator)
         """
 
@@ -489,7 +489,7 @@ class Route53RecoveryReadinessClient(BaseClient):
         self, operation_name: Literal["list_readiness_checks"]
     ) -> ListReadinessChecksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListReadinessChecks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListReadinessChecks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/paginators.html#listreadinesscheckspaginator)
         """
 
@@ -498,7 +498,7 @@ class Route53RecoveryReadinessClient(BaseClient):
         self, operation_name: Literal["list_recovery_groups"]
     ) -> ListRecoveryGroupsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListRecoveryGroups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListRecoveryGroups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/paginators.html#listrecoverygroupspaginator)
         """
 
@@ -507,13 +507,13 @@ class Route53RecoveryReadinessClient(BaseClient):
         self, operation_name: Literal["list_resource_sets"]
     ) -> ListResourceSetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListResourceSets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListResourceSets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/paginators.html#listresourcesetspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_rules"]) -> ListRulesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.25/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListRules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/route53-recovery-readiness.html#Route53RecoveryReadiness.Paginator.ListRules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_readiness/paginators.html#listrulespaginator)
         """
