@@ -13,11 +13,11 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import ReadinessType
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -131,8 +131,8 @@ _RequiredCreateCellRequestRequestTypeDef = TypedDict(
 _OptionalCreateCellRequestRequestTypeDef = TypedDict(
     "_OptionalCreateCellRequestRequestTypeDef",
     {
-        "Cells": List[str],
-        "Tags": Dict[str, str],
+        "Cells": Sequence[str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -181,7 +181,7 @@ _RequiredCreateReadinessCheckRequestRequestTypeDef = TypedDict(
 _OptionalCreateReadinessCheckRequestRequestTypeDef = TypedDict(
     "_OptionalCreateReadinessCheckRequestRequestTypeDef",
     {
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -214,8 +214,8 @@ _RequiredCreateRecoveryGroupRequestRequestTypeDef = TypedDict(
 _OptionalCreateRecoveryGroupRequestRequestTypeDef = TypedDict(
     "_OptionalCreateRecoveryGroupRequestRequestTypeDef",
     {
-        "Cells": List[str],
-        "Tags": Dict[str, str],
+        "Cells": Sequence[str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -244,13 +244,13 @@ _RequiredCreateResourceSetRequestRequestTypeDef = TypedDict(
     {
         "ResourceSetName": str,
         "ResourceSetType": str,
-        "Resources": List["ResourceTypeDef"],
+        "Resources": Sequence["ResourceTypeDef"],
     },
 )
 _OptionalCreateResourceSetRequestRequestTypeDef = TypedDict(
     "_OptionalCreateResourceSetRequestRequestTypeDef",
     {
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -842,7 +842,7 @@ ResourceTypeDef = TypedDict(
     {
         "ComponentId": str,
         "DnsTargetResource": "DNSTargetResourceTypeDef",
-        "ReadinessScopes": List[str],
+        "ReadinessScopes": Sequence[str],
         "ResourceArn": str,
     },
     total=False,
@@ -873,7 +873,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
 )
 
@@ -890,7 +890,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -898,7 +898,7 @@ UpdateCellRequestRequestTypeDef = TypedDict(
     "UpdateCellRequestRequestTypeDef",
     {
         "CellName": str,
-        "Cells": List[str],
+        "Cells": Sequence[str],
     },
 )
 
@@ -936,7 +936,7 @@ UpdateReadinessCheckResponseTypeDef = TypedDict(
 UpdateRecoveryGroupRequestRequestTypeDef = TypedDict(
     "UpdateRecoveryGroupRequestRequestTypeDef",
     {
-        "Cells": List[str],
+        "Cells": Sequence[str],
         "RecoveryGroupName": str,
     },
 )
@@ -957,7 +957,7 @@ UpdateResourceSetRequestRequestTypeDef = TypedDict(
     {
         "ResourceSetName": str,
         "ResourceSetType": str,
-        "Resources": List["ResourceTypeDef"],
+        "Resources": Sequence["ResourceTypeDef"],
     },
 )
 
